Class: Aws::IoTDeviceAdvisor::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTDeviceAdvisor::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotdeviceadvisor/client.rb,
sig/client.rbs
Overview
An API client for IoTDeviceAdvisor. To construct a client, you need to configure a :region and :credentials.
client = Aws::IoTDeviceAdvisor::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateSuiteDefinitionResponseSuccess, _DeleteSuiteDefinitionResponseSuccess, _GetEndpointResponseSuccess, _GetSuiteDefinitionResponseSuccess, _GetSuiteRunReportResponseSuccess, _GetSuiteRunResponseSuccess, _ListSuiteDefinitionsResponseSuccess, _ListSuiteRunsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartSuiteRunResponseSuccess, _StopSuiteRunResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateSuiteDefinitionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_suite_definition(params = {}) ⇒ Types::CreateSuiteDefinitionResponse
Creates a Device Advisor test suite.
-
#delete_suite_definition(params = {}) ⇒ Struct
Deletes a Device Advisor test suite.
-
#get_endpoint(params = {}) ⇒ Types::GetEndpointResponse
Gets information about an Device Advisor endpoint.
-
#get_suite_definition(params = {}) ⇒ Types::GetSuiteDefinitionResponse
Gets information about a Device Advisor test suite.
-
#get_suite_run(params = {}) ⇒ Types::GetSuiteRunResponse
Gets information about a Device Advisor test suite run.
-
#get_suite_run_report(params = {}) ⇒ Types::GetSuiteRunReportResponse
Gets a report download link for a successful Device Advisor qualifying test suite run.
-
#list_suite_definitions(params = {}) ⇒ Types::ListSuiteDefinitionsResponse
Lists the Device Advisor test suites you have created.
-
#list_suite_runs(params = {}) ⇒ Types::ListSuiteRunsResponse
Lists runs of the specified Device Advisor test suite.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to an IoT Device Advisor resource.
-
#start_suite_run(params = {}) ⇒ Types::StartSuiteRunResponse
Starts a Device Advisor test suite run.
-
#stop_suite_run(params = {}) ⇒ Struct
Stops a Device Advisor test suite run that is currently running.
-
#tag_resource(params = {}) ⇒ Struct
Adds to and modifies existing tags of an IoT Device Advisor resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an IoT Device Advisor resource.
-
#update_suite_definition(params = {}) ⇒ Types::UpdateSuiteDefinitionResponse
Updates a Device Advisor test suite.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1178 1179 1180 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1178 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1181 1182 1183 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1181 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1151 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTDeviceAdvisor') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotdeviceadvisor' context[:gem_version] = '1.67.0' Seahorse::Client::Request.new(handlers, context) end |
#create_suite_definition(params = {}) ⇒ Types::CreateSuiteDefinitionResponse
Creates a Device Advisor test suite.
Requires permission to access the CreateSuiteDefinition action.
89 |
# File 'sig/client.rbs', line 89
def create_suite_definition: (
|
#delete_suite_definition(params = {}) ⇒ Struct
Deletes a Device Advisor test suite.
Requires permission to access the DeleteSuiteDefinition action.
100 |
# File 'sig/client.rbs', line 100
def delete_suite_definition: (
|
#get_endpoint(params = {}) ⇒ Types::GetEndpointResponse
Gets information about an Device Advisor endpoint.
110 |
# File 'sig/client.rbs', line 110
def get_endpoint: (
|
#get_suite_definition(params = {}) ⇒ Types::GetSuiteDefinitionResponse
Gets information about a Device Advisor test suite.
Requires permission to access the GetSuiteDefinition action.
130 |
# File 'sig/client.rbs', line 130
def get_suite_definition: (
|
#get_suite_run(params = {}) ⇒ Types::GetSuiteRunResponse
Gets information about a Device Advisor test suite run.
Requires permission to access the GetSuiteRun action.
151 |
# File 'sig/client.rbs', line 151
def get_suite_run: (
|
#get_suite_run_report(params = {}) ⇒ Types::GetSuiteRunReportResponse
Gets a report download link for a successful Device Advisor qualifying test suite run.
Requires permission to access the GetSuiteRunReport action.
162 |
# File 'sig/client.rbs', line 162
def get_suite_run_report: (
|
#list_suite_definitions(params = {}) ⇒ Types::ListSuiteDefinitionsResponse
Lists the Device Advisor test suites you have created.
Requires permission to access the ListSuiteDefinitions action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
174 |
# File 'sig/client.rbs', line 174
def list_suite_definitions: (
|
#list_suite_runs(params = {}) ⇒ Types::ListSuiteRunsResponse
Lists runs of the specified Device Advisor test suite. You can list all runs of the test suite, or the runs of a specific version of the test suite.
Requires permission to access the ListSuiteRuns action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
186 |
# File 'sig/client.rbs', line 186
def list_suite_runs: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to an IoT Device Advisor resource.
Requires permission to access the ListTagsForResource action.
199 |
# File 'sig/client.rbs', line 199
def list_tags_for_resource: (
|
#start_suite_run(params = {}) ⇒ Types::StartSuiteRunResponse
Starts a Device Advisor test suite run.
Requires permission to access the StartSuiteRun action.
212 |
# File 'sig/client.rbs', line 212
def start_suite_run: (
|
#stop_suite_run(params = {}) ⇒ Struct
Stops a Device Advisor test suite run that is currently running.
Requires permission to access the StopSuiteRun action.
232 |
# File 'sig/client.rbs', line 232
def stop_suite_run: (
|
#tag_resource(params = {}) ⇒ Struct
Adds to and modifies existing tags of an IoT Device Advisor resource.
Requires permission to access the TagResource action.
242 |
# File 'sig/client.rbs', line 242
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from an IoT Device Advisor resource.
Requires permission to access the UntagResource action.
252 |
# File 'sig/client.rbs', line 252
def untag_resource: (
|
#update_suite_definition(params = {}) ⇒ Types::UpdateSuiteDefinitionResponse
Updates a Device Advisor test suite.
Requires permission to access the UpdateSuiteDefinition action.
268 |
# File 'sig/client.rbs', line 268
def update_suite_definition: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1171 1172 1173 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1171 def waiter_names [] end |