Class: Aws::IoTDeviceAdvisor::Types::TestCaseRun

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotdeviceadvisor/types.rb

Overview

Provides the test case run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time ⇒ Time

Provides test case run end time.

Returns:

  • (Time)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#failure ⇒ String

Provides test case run failure result.

Returns:

  • (String)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#log_url ⇒ String

Provides test case run log URL.

Returns:

  • (String)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

Provides test case run start time.

Returns:

  • (Time)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Provides the test case run status. Status is one of the following:

  • PASS: Test passed.

  • FAIL: Test failed.

  • PENDING: Test has not started running but is scheduled.

  • RUNNING: Test is running.

  • STOPPING: Test is performing cleanup steps. You will see this status only if you stop a suite run.

  • STOPPED Test is stopped. You will see this status only if you stop a suite run.

  • PASS_WITH_WARNINGS: Test passed with warnings.

  • ERORR: Test faced an error when running due to an internal issue.

Returns:

  • (String)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_definition_id ⇒ String

Provides the test case run definition ID.

Returns:

  • (String)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_definition_name ⇒ String

Provides the test case run definition name.

Returns:

  • (String)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_run_id ⇒ String

Provides the test case run ID.

Returns:

  • (String)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#test_scenarios ⇒ Array<Types::TestCaseScenario>

Provides the test scenarios for the test case run.

Returns:



775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end

#warnings ⇒ String

Provides test case run warnings.

Returns:

  • (String)


775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 775

class TestCaseRun < Struct.new(
  :test_case_run_id,
  :test_case_definition_id,
  :test_case_definition_name,
  :status,
  :start_time,
  :end_time,
  :log_url,
  :warnings,
  :failure,
  :test_scenarios)
  SENSITIVE = []
  include Aws::Structure
end