Class: Aws::IoTDeviceAdvisor::Types::TestCaseScenario

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotdeviceadvisor/types.rb

Overview

Provides test case scenario.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure ⇒ String

Provides test case scenario failure result.

Returns:

  • (String)


836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 836

class TestCaseScenario < Struct.new(
  :test_case_scenario_id,
  :test_case_scenario_type,
  :status,
  :failure,
  :system_message)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Provides the test case scenario status. Status is one of the following:

  • PASS: Test passed.

  • FAIL: Test failed.

  • PENDING: Test has not started running but is scheduled.

  • RUNNING: Test is running.

  • STOPPING: Test is performing cleanup steps. You will see this status only if you stop a suite run.

  • STOPPED Test is stopped. You will see this status only if you stop a suite run.

  • PASS_WITH_WARNINGS: Test passed with warnings.

  • ERORR: Test faced an error when running due to an internal issue.

Returns:

  • (String)


836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 836

class TestCaseScenario < Struct.new(
  :test_case_scenario_id,
  :test_case_scenario_type,
  :status,
  :failure,
  :system_message)
  SENSITIVE = []
  include Aws::Structure
end

#system_message ⇒ String

Provides test case scenario system messages if any.

Returns:

  • (String)


836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 836

class TestCaseScenario < Struct.new(
  :test_case_scenario_id,
  :test_case_scenario_type,
  :status,
  :failure,
  :system_message)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_scenario_id ⇒ String

Provides test case scenario ID.

Returns:

  • (String)


836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 836

class TestCaseScenario < Struct.new(
  :test_case_scenario_id,
  :test_case_scenario_type,
  :status,
  :failure,
  :system_message)
  SENSITIVE = []
  include Aws::Structure
end

#test_case_scenario_type ⇒ String

Provides test case scenario type. Type is one of the following:

  • Advanced

  • Basic

Returns:

  • (String)


836
837
838
839
840
841
842
843
844
# File 'lib/aws-sdk-iotdeviceadvisor/types.rb', line 836

class TestCaseScenario < Struct.new(
  :test_case_scenario_id,
  :test_case_scenario_type,
  :status,
  :failure,
  :system_message)
  SENSITIVE = []
  include Aws::Structure
end