Class: Aws::IoTDeviceAdvisor::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTDeviceAdvisor::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotdeviceadvisor/client.rb
Overview
An API client for IoTDeviceAdvisor. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTDeviceAdvisor::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_suite_definition(params = {}) ⇒ Types::CreateSuiteDefinitionResponse
Creates a Device Advisor test suite.
-
#delete_suite_definition(params = {}) ⇒ Struct
Deletes a Device Advisor test suite.
-
#get_endpoint(params = {}) ⇒ Types::GetEndpointResponse
Gets information about an Device Advisor endpoint.
-
#get_suite_definition(params = {}) ⇒ Types::GetSuiteDefinitionResponse
Gets information about a Device Advisor test suite.
-
#get_suite_run(params = {}) ⇒ Types::GetSuiteRunResponse
Gets information about a Device Advisor test suite run.
-
#get_suite_run_report(params = {}) ⇒ Types::GetSuiteRunReportResponse
Gets a report download link for a successful Device Advisor qualifying test suite run.
-
#list_suite_definitions(params = {}) ⇒ Types::ListSuiteDefinitionsResponse
Lists the Device Advisor test suites you have created.
-
#list_suite_runs(params = {}) ⇒ Types::ListSuiteRunsResponse
Lists runs of the specified Device Advisor test suite.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to an IoT Device Advisor resource.
-
#start_suite_run(params = {}) ⇒ Types::StartSuiteRunResponse
Starts a Device Advisor test suite run.
-
#stop_suite_run(params = {}) ⇒ Struct
Stops a Device Advisor test suite run that is currently running.
-
#tag_resource(params = {}) ⇒ Struct
Adds to and modifies existing tags of an IoT Device Advisor resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an IoT Device Advisor resource.
-
#update_suite_definition(params = {}) ⇒ Types::UpdateSuiteDefinitionResponse
Updates a Device Advisor test suite.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1178 1179 1180 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1178 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1181 1182 1183 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1181 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1151 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTDeviceAdvisor') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotdeviceadvisor' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#create_suite_definition(params = {}) ⇒ Types::CreateSuiteDefinitionResponse
Creates a Device Advisor test suite.
Requires permission to access the [CreateSuiteDefinition] action.
540 541 542 543 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 540 def create_suite_definition(params = {}, = {}) req = build_request(:create_suite_definition, params) req.send_request() end |
#delete_suite_definition(params = {}) ⇒ Struct
Deletes a Device Advisor test suite.
Requires permission to access the [DeleteSuiteDefinition] action.
566 567 568 569 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 566 def delete_suite_definition(params = {}, = {}) req = build_request(:delete_suite_definition, params) req.send_request() end |
#get_endpoint(params = {}) ⇒ Types::GetEndpointResponse
Gets information about an Device Advisor endpoint.
604 605 606 607 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 604 def get_endpoint(params = {}, = {}) req = build_request(:get_endpoint, params) req.send_request() end |
#get_suite_definition(params = {}) ⇒ Types::GetSuiteDefinitionResponse
Gets information about a Device Advisor test suite.
Requires permission to access the [GetSuiteDefinition] action.
664 665 666 667 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 664 def get_suite_definition(params = {}, = {}) req = build_request(:get_suite_definition, params) req.send_request() end |
#get_suite_run(params = {}) ⇒ Types::GetSuiteRunResponse
Gets information about a Device Advisor test suite run.
Requires permission to access the [GetSuiteRun] action.
744 745 746 747 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 744 def get_suite_run(params = {}, = {}) req = build_request(:get_suite_run, params) req.send_request() end |
#get_suite_run_report(params = {}) ⇒ Types::GetSuiteRunReportResponse
Gets a report download link for a successful Device Advisor qualifying test suite run.
Requires permission to access the [GetSuiteRunReport] action.
781 782 783 784 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 781 def get_suite_run_report(params = {}, = {}) req = build_request(:get_suite_run_report, params) req.send_request() end |
#list_suite_definitions(params = {}) ⇒ Types::ListSuiteDefinitionsResponse
Lists the Device Advisor test suites you have created.
Requires permission to access the [ListSuiteDefinitions] action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
831 832 833 834 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 831 def list_suite_definitions(params = {}, = {}) req = build_request(:list_suite_definitions, params) req.send_request() end |
#list_suite_runs(params = {}) ⇒ Types::ListSuiteRunsResponse
Lists runs of the specified Device Advisor test suite. You can list all runs of the test suite, or the runs of a specific version of the test suite.
Requires permission to access the [ListSuiteRuns] action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
893 894 895 896 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 893 def list_suite_runs(params = {}, = {}) req = build_request(:list_suite_runs, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to an IoT Device Advisor resource.
Requires permission to access the [ListTagsForResource] action.
927 928 929 930 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 927 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_suite_run(params = {}) ⇒ Types::StartSuiteRunResponse
Starts a Device Advisor test suite run.
Requires permission to access the [StartSuiteRun] action.
987 988 989 990 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 987 def start_suite_run(params = {}, = {}) req = build_request(:start_suite_run, params) req.send_request() end |
#stop_suite_run(params = {}) ⇒ Struct
Stops a Device Advisor test suite run that is currently running.
Requires permission to access the [StopSuiteRun] action.
1017 1018 1019 1020 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1017 def stop_suite_run(params = {}, = {}) req = build_request(:stop_suite_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds to and modifies existing tags of an IoT Device Advisor resource.
Requires permission to access the [TagResource] action.
1050 1051 1052 1053 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1050 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from an IoT Device Advisor resource.
Requires permission to access the [UntagResource] action.
1081 1082 1083 1084 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1081 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_suite_definition(params = {}) ⇒ Types::UpdateSuiteDefinitionResponse
Updates a Device Advisor test suite.
Requires permission to access the [UpdateSuiteDefinition] action.
1142 1143 1144 1145 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1142 def update_suite_definition(params = {}, = {}) req = build_request(:update_suite_definition, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1171 1172 1173 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1171 def waiter_names [] end |