Class: Aws::IoTDeviceAdvisor::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTDeviceAdvisor::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotdeviceadvisor/client.rb
Overview
An API client for IoTDeviceAdvisor. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTDeviceAdvisor::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_suite_definition(params = {}) ⇒ Types::CreateSuiteDefinitionResponse
Creates a Device Advisor test suite.
-
#delete_suite_definition(params = {}) ⇒ Struct
Deletes a Device Advisor test suite.
-
#get_endpoint(params = {}) ⇒ Types::GetEndpointResponse
Gets information about an Device Advisor endpoint.
-
#get_suite_definition(params = {}) ⇒ Types::GetSuiteDefinitionResponse
Gets information about a Device Advisor test suite.
-
#get_suite_run(params = {}) ⇒ Types::GetSuiteRunResponse
Gets information about a Device Advisor test suite run.
-
#get_suite_run_report(params = {}) ⇒ Types::GetSuiteRunReportResponse
Gets a report download link for a successful Device Advisor qualifying test suite run.
-
#list_suite_definitions(params = {}) ⇒ Types::ListSuiteDefinitionsResponse
Lists the Device Advisor test suites you have created.
-
#list_suite_runs(params = {}) ⇒ Types::ListSuiteRunsResponse
Lists runs of the specified Device Advisor test suite.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to an IoT Device Advisor resource.
-
#start_suite_run(params = {}) ⇒ Types::StartSuiteRunResponse
Starts a Device Advisor test suite run.
-
#stop_suite_run(params = {}) ⇒ Struct
Stops a Device Advisor test suite run that is currently running.
-
#tag_resource(params = {}) ⇒ Struct
Adds to and modifies existing tags of an IoT Device Advisor resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an IoT Device Advisor resource.
-
#update_suite_definition(params = {}) ⇒ Types::UpdateSuiteDefinitionResponse
Updates a Device Advisor test suite.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
476 477 478 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 476 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1183 1184 1185 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1183 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1186 1187 1188 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1186 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1156 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTDeviceAdvisor') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotdeviceadvisor' context[:gem_version] = '1.52.0' Seahorse::Client::Request.new(handlers, context) end |
#create_suite_definition(params = {}) ⇒ Types::CreateSuiteDefinitionResponse
Creates a Device Advisor test suite.
Requires permission to access the [CreateSuiteDefinition] action.
545 546 547 548 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 545 def create_suite_definition(params = {}, = {}) req = build_request(:create_suite_definition, params) req.send_request() end |
#delete_suite_definition(params = {}) ⇒ Struct
Deletes a Device Advisor test suite.
Requires permission to access the [DeleteSuiteDefinition] action.
571 572 573 574 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 571 def delete_suite_definition(params = {}, = {}) req = build_request(:delete_suite_definition, params) req.send_request() end |
#get_endpoint(params = {}) ⇒ Types::GetEndpointResponse
Gets information about an Device Advisor endpoint.
609 610 611 612 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 609 def get_endpoint(params = {}, = {}) req = build_request(:get_endpoint, params) req.send_request() end |
#get_suite_definition(params = {}) ⇒ Types::GetSuiteDefinitionResponse
Gets information about a Device Advisor test suite.
Requires permission to access the [GetSuiteDefinition] action.
669 670 671 672 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 669 def get_suite_definition(params = {}, = {}) req = build_request(:get_suite_definition, params) req.send_request() end |
#get_suite_run(params = {}) ⇒ Types::GetSuiteRunResponse
Gets information about a Device Advisor test suite run.
Requires permission to access the [GetSuiteRun] action.
749 750 751 752 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 749 def get_suite_run(params = {}, = {}) req = build_request(:get_suite_run, params) req.send_request() end |
#get_suite_run_report(params = {}) ⇒ Types::GetSuiteRunReportResponse
Gets a report download link for a successful Device Advisor qualifying test suite run.
Requires permission to access the [GetSuiteRunReport] action.
786 787 788 789 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 786 def get_suite_run_report(params = {}, = {}) req = build_request(:get_suite_run_report, params) req.send_request() end |
#list_suite_definitions(params = {}) ⇒ Types::ListSuiteDefinitionsResponse
Lists the Device Advisor test suites you have created.
Requires permission to access the [ListSuiteDefinitions] action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
836 837 838 839 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 836 def list_suite_definitions(params = {}, = {}) req = build_request(:list_suite_definitions, params) req.send_request() end |
#list_suite_runs(params = {}) ⇒ Types::ListSuiteRunsResponse
Lists runs of the specified Device Advisor test suite. You can list all runs of the test suite, or the runs of a specific version of the test suite.
Requires permission to access the [ListSuiteRuns] action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
898 899 900 901 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 898 def list_suite_runs(params = {}, = {}) req = build_request(:list_suite_runs, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags attached to an IoT Device Advisor resource.
Requires permission to access the [ListTagsForResource] action.
932 933 934 935 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 932 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_suite_run(params = {}) ⇒ Types::StartSuiteRunResponse
Starts a Device Advisor test suite run.
Requires permission to access the [StartSuiteRun] action.
992 993 994 995 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 992 def start_suite_run(params = {}, = {}) req = build_request(:start_suite_run, params) req.send_request() end |
#stop_suite_run(params = {}) ⇒ Struct
Stops a Device Advisor test suite run that is currently running.
Requires permission to access the [StopSuiteRun] action.
1022 1023 1024 1025 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1022 def stop_suite_run(params = {}, = {}) req = build_request(:stop_suite_run, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds to and modifies existing tags of an IoT Device Advisor resource.
Requires permission to access the [TagResource] action.
1055 1056 1057 1058 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1055 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from an IoT Device Advisor resource.
Requires permission to access the [UntagResource] action.
1086 1087 1088 1089 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1086 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_suite_definition(params = {}) ⇒ Types::UpdateSuiteDefinitionResponse
Updates a Device Advisor test suite.
Requires permission to access the [UpdateSuiteDefinition] action.
1147 1148 1149 1150 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1147 def update_suite_definition(params = {}, = {}) req = build_request(:update_suite_definition, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1176 1177 1178 |
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1176 def waiter_names [] end |