Class: Aws::IoTDeviceAdvisor::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-iotdeviceadvisor/client.rb

Overview

An API client for IoTDeviceAdvisor. To construct a client, you need to configure a `:region` and `:credentials`.

client = Aws::IoTDeviceAdvisor::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials. This can be an instance of any one of the following classes:

    • `Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • `Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • `Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • `Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • `Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • `Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • `Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • `Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • `Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When `:credentials` are not configured directly, the following locations will be searched for credentials:

    • `Aws.config`

    • The `:access_key_id`, `:secret_access_key`, and `:session_token` options.

    • ENV, ENV

    • `~/.aws/credentials`

    • `~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of `Aws::InstanceProfileCredentails` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting ENV to true.

  • :region (required, String)

    The AWS region to connect to. The configured `:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to `true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in `adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :client_side_monitoring (Boolean) — default: false

    When `true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When `true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in `standard` and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    Set to true to disable SDK automatically adding host prefix to default service endpoint when available.

  • :endpoint (String)

    The client endpoint is normally constructed from the `:region` option. You should only configure an `:endpoint` when connecting to test or custom endpoints. This should be a valid HTTP(S) URI.

  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to `true`, endpoint discovery will be enabled for operations when available.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the `:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in `standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at HOME/.aws/credentials. When not specified, 'default' is used.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the `legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the `legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the `legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the `legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the `legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • `legacy` - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • `standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • `adaptive` - An experimental retry mode that includes all the functionality of `standard` mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :secret_access_key (String)
  • :session_token (String)
  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :use_dualstack_endpoint (Boolean)

    When set to `true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to `true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When `true`, request parameters are validated before sending the request.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like 'proxy.com:123'.

  • :http_open_timeout (Float) — default: 15

    The number of seconds to wait when opening a HTTP session before raising a `Timeout::Error`.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to `nil` which disables this behaviour. This value can safely be set per request on the session.

  • :ssl_timeout (Float) — default: nil

    Sets the SSL timeout in seconds.

  • :http_wire_trace (Boolean) — default: false

    When `true`, HTTP debug output will be sent to the `:logger`.

  • :ssl_verify_peer (Boolean) — default: true

    When `true`, SSL peer certificates are verified when establishing a connection.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass `:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass `:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.



346
347
348
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 346

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1006
1007
1008
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1006

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1009
1010
1011
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 1009

def errors_module
  Errors
end

Instance Method Details

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


984
985
986
987
988
989
990
991
992
993
994
995
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 984

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config)
  context[:gem_name] = 'aws-sdk-iotdeviceadvisor'
  context[:gem_version] = '1.13.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_suite_definition(params = {}) ⇒ Types::CreateSuiteDefinitionResponse

Creates a Device Advisor test suite.

Requires permission to access the [CreateSuiteDefinition] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.create_suite_definition({
  suite_definition_configuration: {
    suite_definition_name: "SuiteDefinitionName",
    devices: [
      {
        thing_arn: "AmazonResourceName",
        certificate_arn: "AmazonResourceName",
      },
    ],
    intended_for_qualification: false,
    root_group: "RootGroup",
    device_permission_role_arn: "AmazonResourceName",
  },
  tags: {
    "String128" => "String256",
  },
})

Response structure


resp.suite_definition_id #=> String
resp.suite_definition_arn #=> String
resp.suite_definition_name #=> String
resp.created_at #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_configuration (Types::SuiteDefinitionConfiguration)

    Creates a Device Advisor test suite with suite definition configuration.

  • :tags (Hash<String,String>)

    The tags to be attached to the suite definition.

Returns:



403
404
405
406
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 403

def create_suite_definition(params = {}, options = {})
  req = build_request(:create_suite_definition, params)
  req.send_request(options)
end

#delete_suite_definition(params = {}) ⇒ Struct

Deletes a Device Advisor test suite.

Requires permission to access the [DeleteSuiteDefinition] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.delete_suite_definition({
  suite_definition_id: "UUID", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_id (required, String)

    Suite definition ID of the test suite to be deleted.

Returns:

  • (Struct)

    Returns an empty response.



429
430
431
432
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 429

def delete_suite_definition(params = {}, options = {})
  req = build_request(:delete_suite_definition, params)
  req.send_request(options)
end

#get_endpoint(params = {}) ⇒ Types::GetEndpointResponse

Gets information about an Device Advisor endpoint.

Examples:

Request syntax with placeholder values


resp = client.get_endpoint({
  thing_arn: "AmazonResourceName",
  certificate_arn: "AmazonResourceName",
})

Response structure


resp.endpoint #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :thing_arn (String)

    The thing ARN of the device. This is an optional parameter.

  • :certificate_arn (String)

    The certificate ARN of the device. This is an optional parameter.

Returns:



459
460
461
462
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 459

def get_endpoint(params = {}, options = {})
  req = build_request(:get_endpoint, params)
  req.send_request(options)
end

#get_suite_definition(params = {}) ⇒ Types::GetSuiteDefinitionResponse

Gets information about a Device Advisor test suite.

Requires permission to access the [GetSuiteDefinition] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.get_suite_definition({
  suite_definition_id: "UUID", # required
  suite_definition_version: "SuiteDefinitionVersion",
})

Response structure


resp.suite_definition_id #=> String
resp.suite_definition_arn #=> String
resp.suite_definition_version #=> String
resp.latest_version #=> String
resp.suite_definition_configuration.suite_definition_name #=> String
resp.suite_definition_configuration.devices #=> Array
resp.suite_definition_configuration.devices[0].thing_arn #=> String
resp.suite_definition_configuration.devices[0].certificate_arn #=> String
resp.suite_definition_configuration.intended_for_qualification #=> Boolean
resp.suite_definition_configuration.root_group #=> String
resp.suite_definition_configuration.device_permission_role_arn #=> String
resp.created_at #=> Time
resp.last_modified_at #=> Time
resp.tags #=> Hash
resp.tags["String128"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_id (required, String)

    Suite definition ID of the test suite to get.

  • :suite_definition_version (String)

    Suite definition version of the test suite to get.

Returns:



516
517
518
519
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 516

def get_suite_definition(params = {}, options = {})
  req = build_request(:get_suite_definition, params)
  req.send_request(options)
end

#get_suite_run(params = {}) ⇒ Types::GetSuiteRunResponse

Gets information about a Device Advisor test suite run.

Requires permission to access the [GetSuiteRun] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.get_suite_run({
  suite_definition_id: "UUID", # required
  suite_run_id: "UUID", # required
})

Response structure


resp.suite_definition_id #=> String
resp.suite_definition_version #=> String
resp.suite_run_id #=> String
resp.suite_run_arn #=> String
resp.suite_run_configuration.primary_device.thing_arn #=> String
resp.suite_run_configuration.primary_device.certificate_arn #=> String
resp.suite_run_configuration.selected_test_list #=> Array
resp.suite_run_configuration.selected_test_list[0] #=> String
resp.suite_run_configuration.parallel_run #=> Boolean
resp.test_result.groups #=> Array
resp.test_result.groups[0].group_id #=> String
resp.test_result.groups[0].group_name #=> String
resp.test_result.groups[0].tests #=> Array
resp.test_result.groups[0].tests[0].test_case_run_id #=> String
resp.test_result.groups[0].tests[0].test_case_definition_id #=> String
resp.test_result.groups[0].tests[0].test_case_definition_name #=> String
resp.test_result.groups[0].tests[0].status #=> String, one of "PASS", "FAIL", "CANCELED", "PENDING", "RUNNING", "STOPPING", "STOPPED", "PASS_WITH_WARNINGS", "ERROR"
resp.test_result.groups[0].tests[0].start_time #=> Time
resp.test_result.groups[0].tests[0].end_time #=> Time
resp.test_result.groups[0].tests[0].log_url #=> String
resp.test_result.groups[0].tests[0].warnings #=> String
resp.test_result.groups[0].tests[0].failure #=> String
resp.start_time #=> Time
resp.end_time #=> Time
resp.status #=> String, one of "PASS", "FAIL", "CANCELED", "PENDING", "RUNNING", "STOPPING", "STOPPED", "PASS_WITH_WARNINGS", "ERROR"
resp.error_reason #=> String
resp.tags #=> Hash
resp.tags["String128"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_id (required, String)

    Suite definition ID for the test suite run.

  • :suite_run_id (required, String)

    Suite run ID for the test suite run.

Returns:



589
590
591
592
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 589

def get_suite_run(params = {}, options = {})
  req = build_request(:get_suite_run, params)
  req.send_request(options)
end

#get_suite_run_report(params = {}) ⇒ Types::GetSuiteRunReportResponse

Gets a report download link for a successful Device Advisor qualifying test suite run.

Requires permission to access the [GetSuiteRunReport] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.get_suite_run_report({
  suite_definition_id: "UUID", # required
  suite_run_id: "UUID", # required
})

Response structure


resp.qualification_report_download_url #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_id (required, String)

    Suite definition ID of the test suite.

  • :suite_run_id (required, String)

    Suite run ID of the test suite run.

Returns:



626
627
628
629
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 626

def get_suite_run_report(params = {}, options = {})
  req = build_request(:get_suite_run_report, params)
  req.send_request(options)
end

#list_suite_definitions(params = {}) ⇒ Types::ListSuiteDefinitionsResponse

Lists the Device Advisor test suites you have created.

Requires permission to access the [ListSuiteDefinitions] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_suite_definitions({
  max_results: 1,
  next_token: "Token",
})

Response structure


resp.suite_definition_information_list #=> Array
resp.suite_definition_information_list[0].suite_definition_id #=> String
resp.suite_definition_information_list[0].suite_definition_name #=> String
resp.suite_definition_information_list[0].default_devices #=> Array
resp.suite_definition_information_list[0].default_devices[0].thing_arn #=> String
resp.suite_definition_information_list[0].default_devices[0].certificate_arn #=> String
resp.suite_definition_information_list[0].intended_for_qualification #=> Boolean
resp.suite_definition_information_list[0].created_at #=> Time
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :max_results (Integer)

    The maximum number of results to return at once.

  • :next_token (String)

    A token used to get the next set of results.

Returns:



673
674
675
676
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 673

def list_suite_definitions(params = {}, options = {})
  req = build_request(:list_suite_definitions, params)
  req.send_request(options)
end

#list_suite_runs(params = {}) ⇒ Types::ListSuiteRunsResponse

Lists runs of the specified Device Advisor test suite. You can list all runs of the test suite, or the runs of a specific version of the test suite.

Requires permission to access the [ListSuiteRuns] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_suite_runs({
  suite_definition_id: "UUID",
  suite_definition_version: "SuiteDefinitionVersion",
  max_results: 1,
  next_token: "Token",
})

Response structure


resp.suite_runs_list #=> Array
resp.suite_runs_list[0].suite_definition_id #=> String
resp.suite_runs_list[0].suite_definition_version #=> String
resp.suite_runs_list[0].suite_definition_name #=> String
resp.suite_runs_list[0].suite_run_id #=> String
resp.suite_runs_list[0].created_at #=> Time
resp.suite_runs_list[0].started_at #=> Time
resp.suite_runs_list[0].end_at #=> Time
resp.suite_runs_list[0].status #=> String, one of "PASS", "FAIL", "CANCELED", "PENDING", "RUNNING", "STOPPING", "STOPPED", "PASS_WITH_WARNINGS", "ERROR"
resp.suite_runs_list[0].passed #=> Integer
resp.suite_runs_list[0].failed #=> Integer
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_id (String)

    Lists the test suite runs of the specified test suite based on suite definition ID.

  • :suite_definition_version (String)

    Must be passed along with `suiteDefinitionId`. Lists the test suite runs of the specified test suite based on suite definition version.

  • :max_results (Integer)

    The maximum number of results to return at once.

  • :next_token (String)

    A token to retrieve the next set of results.

Returns:



735
736
737
738
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 735

def list_suite_runs(params = {}, options = {})
  req = build_request(:list_suite_runs, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse

Lists the tags attached to an IoT Device Advisor resource.

Requires permission to access the [ListTagsForResource] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  resource_arn: "AmazonResourceName", # required
})

Response structure


resp.tags #=> Hash
resp.tags["String128"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The ARN of the IoT Device Advisor resource.

Returns:



768
769
770
771
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 768

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#start_suite_run(params = {}) ⇒ Types::StartSuiteRunResponse

Starts a Device Advisor test suite run.

Requires permission to access the [StartSuiteRun] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.start_suite_run({
  suite_definition_id: "UUID", # required
  suite_definition_version: "SuiteDefinitionVersion",
  suite_run_configuration: {
    primary_device: {
      thing_arn: "AmazonResourceName",
      certificate_arn: "AmazonResourceName",
    },
    selected_test_list: ["UUID"],
    parallel_run: false,
  },
  tags: {
    "String128" => "String256",
  },
})

Response structure


resp.suite_run_id #=> String
resp.suite_run_arn #=> String
resp.created_at #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_id (required, String)

    Suite definition ID of the test suite.

  • :suite_definition_version (String)

    Suite definition version of the test suite.

  • :suite_run_configuration (Types::SuiteRunConfiguration)

    Suite run configuration.

  • :tags (Hash<String,String>)

    The tags to be attached to the suite run.

Returns:



825
826
827
828
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 825

def start_suite_run(params = {}, options = {})
  req = build_request(:start_suite_run, params)
  req.send_request(options)
end

#stop_suite_run(params = {}) ⇒ Struct

Stops a Device Advisor test suite run that is currently running.

Requires permission to access the [StopSuiteRun] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.stop_suite_run({
  suite_definition_id: "UUID", # required
  suite_run_id: "UUID", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_id (required, String)

    Suite definition ID of the test suite run to be stopped.

  • :suite_run_id (required, String)

    Suite run ID of the test suite run to be stopped.

Returns:

  • (Struct)

    Returns an empty response.



855
856
857
858
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 855

def stop_suite_run(params = {}, options = {})
  req = build_request(:stop_suite_run, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Adds to and modifies existing tags of an IoT Device Advisor resource.

Requires permission to access the [TagResource] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.tag_resource({
  resource_arn: "AmazonResourceName", # required
  tags: { # required
    "String128" => "String256",
  },
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The resource ARN of an IoT Device Advisor resource.

  • :tags (required, Hash<String,String>)

    The tags to be attached to the IoT Device Advisor resource.

Returns:

  • (Struct)

    Returns an empty response.



887
888
889
890
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 887

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Removes tags from an IoT Device Advisor resource.

Requires permission to access the [UntagResource] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.untag_resource({
  resource_arn: "AmazonResourceName", # required
  tag_keys: ["String128"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The resource ARN of an IoT Device Advisor resource.

  • :tag_keys (required, Array<String>)

    List of tag keys to remove from the IoT Device Advisor resource.

Returns:

  • (Struct)

    Returns an empty response.



917
918
919
920
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 917

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#update_suite_definition(params = {}) ⇒ Types::UpdateSuiteDefinitionResponse

Updates a Device Advisor test suite.

Requires permission to access the [UpdateSuiteDefinition] action.

[1]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions

Examples:

Request syntax with placeholder values


resp = client.update_suite_definition({
  suite_definition_id: "UUID", # required
  suite_definition_configuration: {
    suite_definition_name: "SuiteDefinitionName",
    devices: [
      {
        thing_arn: "AmazonResourceName",
        certificate_arn: "AmazonResourceName",
      },
    ],
    intended_for_qualification: false,
    root_group: "RootGroup",
    device_permission_role_arn: "AmazonResourceName",
  },
})

Response structure


resp.suite_definition_id #=> String
resp.suite_definition_arn #=> String
resp.suite_definition_name #=> String
resp.suite_definition_version #=> String
resp.created_at #=> Time
resp.last_updated_at #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :suite_definition_id (required, String)

    Suite definition ID of the test suite to be updated.

  • :suite_definition_configuration (Types::SuiteDefinitionConfiguration)

    Updates a Device Advisor test suite with suite definition configuration.

Returns:



975
976
977
978
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 975

def update_suite_definition(params = {}, options = {})
  req = build_request(:update_suite_definition, params)
  req.send_request(options)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


999
1000
1001
# File 'lib/aws-sdk-iotdeviceadvisor/client.rb', line 999

def waiter_names
  []
end